/* gcompris - gcompris_im.h
 *
 * Time-stamp: <2007-08-22 01:21:25 bruno>
 *
 * Copyright (C) 2005 Bruno Coudoin
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 */

/*****************************************************************************/
/* this files gives access to im_context for gcompris_board.                 */
/*****************************************************************************/

#ifndef GCOMPRIS_IM_H
#define GCOMPRIS_IM_H

void gc_im_init(GtkWidget *window);
void gc_im_reset();

#endif
